Crate kcr_marin3r_3scale_net

Crate kcr_marin3r_3scale_net 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the marin3r.3scale.net group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

marin3r.3scale.net/v1alpha1

  • EnvoyConfigRevision
  • EnvoyConfig

Modules

v1alpha1